"use strict";

const { images_url } = require("../../../../constants");

const GAMEDEV_THEMES = [
    {
        title: "Dessin et création 2D",
        image: "learning_theme_2d.png",
        details: [
            "Création de décors et de personnages",
            "Dessin sur ordinateur, pixel art, vectoriel",
            "Animations 2D",
        ],
    },
    {
        title: "Musique et sons",
        image: "learning_theme_sound.png",
        details: ["Logiciels de son et synthétiseurs", "Composition", "Prise de son", "Mixage"],
    },
    {
        title: "Écriture",
        image: "learning_theme_write.png",
        details: [
            "Écrire une histoire, construire une narration",
            "Imaginer des mondes et des personnages",
        ],
    },
    {
        title: "Conception",
        image: "learning_theme_conception.png",
        details: [
            "Concevoir les différents éléments qui composent le jeu",
            "Développer les mécanismes de gameplay",
        ],
    },
    {
        title: "Programmation",
        image: "learning_theme_coding.png",
        details: [
            "Apprendre pas à pas à coder avec différents langages de programmation",
            "Découvrir les bases du web en créant des mini-jeux en lignes",
        ],
    },
    {
        title: "Mathématiques",
        image: "learning_theme_math.png",
        comment:
            "<em>Créer un jeu vidéo c'est l'occasion de découvrir plein de sujets en maths et en physique tout en s'amusant !</em>",
        details: [
            "Algorithmie",
            "Logique (algèbre booléen)",
            "Géométrie",
            "Trigonométrie",
            "Algèbre linéaire",
            "Repères 2D / 3D",
            "Vecteurs 2D / 3D",
            "Newton",
            "...",
        ],
    },
    {
        title: "Travail d'équipe",
        image: "learning_theme_team.png",
        comment: `
            <em>
                Faire son jeu tout seul c'est bien mais ça peut être long !
                <br />Créer des jeux c'est aussi l'occasion de se mettre à plusieurs pour tirer le meilleur parti des différents talents de chacun.
            </em>`,
        details: ["Gestion de projet", "Méthodologie", "Communication"],
    },
    {
        title: "Logiciels libres, GNU/Linux",
        image: "learning_theme_linux.png",
        comment:
            "<em>Nous utilisons essentiellement des logiciels libres sur Linux.<br />C'est donc une bonne occasion de découvrir et démystifier tout ça en douceur !</em>",
        details: ["Ubuntu / Debian", "GIMP", "LMMS", "Audacity", "Pencil2d", "..."],
    },
];

class GameStudioClub {
    render() {
        return {
            tag: "section",
            typeof: "EducationalOrganization",
            contents: [
                {
                    tag: "div",
                    class: "title-banner game-banner",
                    id: "game-studio-club", // anchor id
                    contents: [{ tag: "h2", contents: "Game Studio Club", property: "name" }],
                },
                {
                    tag: "div",
                    class: "special-announcement",
                    contents: [
                        {
                            tag: "div",
                            class: "page-contents-center",
                            contents: [
                                {
                                    tag: "p",
                                    contents: `
                                    Démarrage des séances à partir du <blue>1er Mars 2021</blue>
                                    `,
                                },
                            ],
                        },
                    ],
                },
                {
                    tag: "div",
                    class: "section-contents page-contents-center",
                    contents: [
                        {
                            tag: "div",
                            class: "full-row",
                            contents: [
                                {
                                    tag: "h3",
                                    class: "big",
                                    contents:
                                        "Apprendre à créer un <blue>jeu vidéo</blue> de A à Z",
                                    property: "headline",
                                },
                                {
                                    tag: "strong",
                                    contents:
                                        "La création d'un jeu vidéo c'est l'occasion d'aborder plein de choses différentes !",
                                },
                                {
                                    tag: "p",
                                    contents:
                                        "<em><b><blue>Aucun prérequis nécessaire</blue></b>. Pas besoin d'être fort en maths ou en informatique, le but est d'apprendre et se détendre !</em>",
                                },
                            ],
                        },
                        {
                            tag: "div",
                            class: "practical-infos",
                            contents: [
                                {
                                    tag: "div",
                                    class: "info-item",
                                    property: "about",
                                    contents: [
                                        { tag: "strong", contents: "Ça se passe où ?" },
                                        {
                                            tag: "span",

                                            contents:
                                                "Dans les locaux,<br/><em>32 rue Simon Vialet, passage du Cheminou<br/>07240 Vernoux en Vivarais</em>",
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "info-item",
                                    property: "about",
                                    contents: [
                                        { tag: "strong", contents: "Pour qui ?" },
                                        {
                                            tag: "span",
                                            contents: `Tout le monde à partir de <b><blue>12 ans</blue></b>.
                                            <br><br><b><blue>Ados</blue></b> et <b><blue>adultes</blue></b>.
                                            `,
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "info-item",
                                    property: "about",
                                    contents: [
                                        {
                                            tag: "strong",
                                            contents: "Contact",
                                        },
                                        {
                                            tag: "a",
                                            href: "tel:+33475780872",
                                            contents: "04 75 78 08 72",
                                            property: "telephone",
                                        },
                                        {
                                            tag: "a",
                                            href: "mailto:contact@kuadrado-software.fr",
                                            contents: "contact@kuadrado-software.fr",
                                            property: "email",
                                        },
                                    ],
                                },
                            ],
                        },
                        {
                            tag: "div",
                            class: "list-wrapper",
                            property: "hasPart",
                            contents: [
                                {
                                    tag: "ul",
                                    class: "learning-themes",
                                    contents: GAMEDEV_THEMES.map(li => {
                                        return {
                                            tag: "li",
                                            class: "learning-theme",
                                            typeof: "ListItem",
                                            contents: [
                                                {
                                                    tag: "strong",
                                                    class: "title",
                                                    contents: li.title,
                                                    property: "name",
                                                },
                                                {
                                                    tag: "img",
                                                    alt: `learning theme image ${li.title}`,
                                                    src: `${images_url}${li.image}`,
                                                    property: "image",
                                                },
                                                {
                                                    tag: "div",
                                                    class: "details",
                                                    property: "description",
                                                    contents: [
                                                        li.comment && {
                                                            tag: "div",
                                                            class: "comment",
                                                            contents: li.comment,
                                                        },
                                                        {
                                                            tag: "ul",
                                                            contents: li.details.map(d => {
                                                                return {
                                                                    tag: "li",
                                                                    contents: d,
                                                                };
                                                            }),
                                                        },
                                                    ],
                                                },
                                            ],
                                        };
                                    }),
                                },
                            ],
                        },
                        {
                            tag: "div",
                            class: "infos-inscriptions full-row",
                            property: "about",
                            contents: [
                                {
                                    tag: "div",
                                    class: "groups",
                                    contents: [
                                        {
                                            tag: "h3",
                                            contents: "Groupes",
                                        },
                                        {
                                            tag: "p",
                                            contents:
                                                "Les groupes sont de <b><blue>5 personnes</blue></b> maximum.",
                                        },
                                        {
                                            tag: "div",
                                            class: "table-wrapper",
                                            contents: [
                                                {
                                                    tag: "table",
                                                    contents: [
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Mardi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "16h - 19h",
                                                                },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Mercredi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "14h - 17h",
                                                                },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                { tag: "td", contents: "Jeudi" },
                                                                {
                                                                    tag: "td",
                                                                    contents: "16h - 19h",
                                                                },
                                                            ],
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                        {
                                            tag: "p",
                                            contents: `
                                            Les séances sont accessibles sur des plages horaires de 3 heures,
                                            mais les participants peuvent arriver et repartir à l'heure qu'ils souhaitent, 
                                            ils ne sont pas obligés de rester les 3 heures.
                                            <br><br>
                                            Le club est ouvert à toute personne à partir de <b><blue>12 ans</blue></b>, 
                                            adolescent ou adulte, et les groupes sont aussi <b><blue>intergénérationnels</blue></b> que possible.
                                            `,
                                        },
                                    ],
                                },
                                {
                                    tag: "div",
                                    class: "pricing",
                                    contents: [
                                        {
                                            tag: "h3",
                                            contents: "Inscription, fonctionnement et tarifs",
                                        },
                                        {
                                            tag: "p",
                                            contents: `Vous pouvez vous inscrire dans un des groupes pour un mois ou un trimestre.<br /><br />
                                                Le matériel informatique (pc portable, souris, tablette graphique) est fourni sur place, mais vous pouvez amener votre propre ordinateur portable si vous le souhaitez.
                                            `,
                                        },
                                        {
                                            tag: "div",
                                            class: "table-wrapper",
                                            contents: [
                                                {
                                                    tag: "table",
                                                    contents: [
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                {
                                                                    tag: "td",
                                                                    contents: "Abonnement 1 mois",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents: "(4 séances)",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents:
                                                                        "<b><blue>60€</blue></b>",
                                                                },
                                                            ],
                                                        },
                                                        {
                                                            tag: "tr",
                                                            contents: [
                                                                {
                                                                    tag: "td",
                                                                    contents:
                                                                        "Abonnement 1 trimestre",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents: "(12 séances)",
                                                                },
                                                                {
                                                                    tag: "td",
                                                                    contents:
                                                                        "<b><blue>160€</blue></b>",
                                                                },
                                                            ],
                                                        },
                                                    ],
                                                },
                                            ],
                                        },
                                        {
                                            tag: "div",
                                            class:"documents",
                                            contents: [
                                                {
                                                    tag: "div",
                                                    contents: "Télécharger la fiche d'inscription",
                                                },
                                                {
                                                    tag:"div",
                                                    class: "links",
                                                    contents: [
                                                        {
                                                            tag: "a",
                                                            class: "download-link",
                                                            download: "fiche-inscription",
                                                            href: "/assets/documents/fiche-inscription.pdf",
                                                            contents: "PDF",
                                                        },
                                                        {
                                                            tag: "a",
                                                            class: "download-link",
                                                            download: "fiche-inscription",
                                                            href: "/assets/documents/fiche-inscription.odt",
                                                            contents: "Libre Office",
                                                        },
                                                    ]
                                                }
          
                                            ],
                                        },
                                    ],
                                },
                            ],
                        },
                        {
                            tag: "div",
                            class: "teacher",
                            contents: [
    
                                {
                                    tag: "div",
                                    class: "teacher-card",
                                    contents: [
                                        {
                                            tag: "h3",
                                            contents: "Animé par",
                                        },
                                        {
                                            tag: "div",
                                            class: "pic",
                                            contents: [
                                                {
                                                    tag: "img",
                                                    src:
                                                        "/assets/images/pijar_profile_lt_square.png",
                                                },
                                            ],
                                        },
                                        {
                                            tag:"div",
                                            class:"infos-text",
                                            contents: [
                                                {
                                                    tag:"h4",
                                                    contents: "Pierre Jarriges"
                                                },
                                                {
                                                    tag: "p",
                                                    contents: "Développeur jeu vidéo, auteur BD, compositeur."
                                                }
                                            ]
                                        }
                                    ],
                                },
                            ],
                        },
                    ],
                },
            ],
        };
    }
}

module.exports = GameStudioClub;
